==> featuretools-0.1.5.tar.gz: featuretools-0.1.5/featuretools/tests/entityset_tests/test_es.py <==
from featuretools import variable_types, Relationship
from ..testing_utils import make_ecommerce_entityset
import pytest


@pytest.fixture
def es():
    return make_ecommerce_entityset()


@pytest.fixture
def glob_es():
    return make_ecommerce_entityset(split_by_time=True)


@pytest.fixture
def gzip_es():
    return make_ecommerce_entityset(compressed=True)


@pytest.fixture
def gzip_glob_es():
    return make_ecommerce_entityset(split_by_time=True, compressed=True)


def test_cannot_readd_relationships_that_already_exists(es):
    before_len = len(es.relationships)
    es.add_relationship(es.relationships[0])
    after_len = len(es.relationships)
    assert before_len == after_len


def test_add_relationships_convert_type(es):
    for r in es.relationships:
        try:
            assert isinstance(r.parent_variable, variable_types.Discrete)
            assert isinstance(r.child_variable, variable_types.Discrete)
        except:
            assert isinstance(r.parent_variable, variable_types.Discrete)
            assert isinstance(r.child_variable, variable_types.Discrete)


def test_get_forward_entities(es):
    entities = es.get_forward_entities('log')
    assert entities == set(['sessions', 'products'])


def test_get_backward_entities(es):
    entities = es.get_backward_entities('sessions')
    assert entities == set(['log'])


def test_get_forward_entities_deep(es):
    entities = es.get_forward_entities('log', 'deep')
    assert entities == set(['sessions', 'customers', 'products', 'regions', 'cohorts'])


def test_get_backward_entities_deep(es):
    entities = es.get_backward_entities('customers', deep=True)
    assert entities == set(['log', 'sessions'])


def test_get_forward_relationships(es):
    relationships = es.get_forward_relationships('log')
    assert len(relationships) == 2
    assert relationships[0].parent_entity.id == 'sessions'
    assert relationships[0].child_entity.id == 'log'
    assert relationships[1].parent_entity.id == 'products'
    assert relationships[1].child_entity.id == 'log'

    relationships = es.get_forward_relationships('sessions')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'customers'
    assert relationships[0].child_entity.id == 'sessions'


def test_get_backward_relationships(es):
    relationships = es.get_backward_relationships('sessions')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'sessions'
    assert relationships[0].child_entity.id == 'log'

    relationships = es.get_backward_relationships('customers')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'customers'
    assert relationships[0].child_entity.id == 'sessions'


def test_find_forward_path(es):
    path = es.find_forward_path('log', 'customers')

    assert len(path) == 2
    assert path[0].child_entity.id == 'log'
    assert path[0].parent_entity.id == 'sessions'
    assert path[1].child_entity.id == 'sessions'
    assert path[1].parent_entity.id == 'customers'


def test_find_backward_path(es):
    path = es.find_backward_path('customers', 'log')

    assert len(path) == 2
    assert path[0].child_entity.id == 'sessions'
    assert path[0].parent_entity.id == 'customers'
    assert path[1].child_entity.id == 'log'
    assert path[1].parent_entity.id == 'sessions'


def test_find_path(es):
    path, forward = es.find_path('products', 'customers',
                                 include_num_forward=True)

    assert len(path) == 3
    assert forward == 2
    assert path[0].child_entity.id == 'log'
    assert path[0].parent_entity.id == 'products'
    assert path[1].child_entity.id == 'log'
    assert path[1].parent_entity.id == 'sessions'
    assert path[2].child_entity.id == 'sessions'
    assert path[2].parent_entity.id == 'customers'


def test_raise_key_error_missing_entity(es):
    with pytest.raises(KeyError):
        es["this entity doesn't exist"]


def test_add_parent_not_id_varible(es):
    with pytest.raises(AttributeError):
        es.add_relationship(Relationship(es['regions']['language'],
                                         es['customers']['region_id']))


def test_glob_entityset(es, glob_es):
    df_1 = es.entity_stores['log'].df
    df_2 = glob_es.entity_stores['log'].df
    assert df_1.equals(df_2)


def test_gzip_entityset(es, gzip_es):
    df_1 = es.entity_stores['log'].df
    df_2 = gzip_es.entity_stores['log'].df
    assert df_1.equals(df_2)


def test_gzip_glob_entityset(es, gzip_glob_es):
    df_1 = es.entity_stores['log'].df
    df_2 = gzip_glob_es.entity_stores['log'].df
    assert df_1.equals(df_2)

==> featuretools-0.1.21.tar.gz: featuretools-0.1.21/featuretools/tests/entityset_tests/test_es.py <==
import os
import shutil

import pytest

from ..testing_utils import make_ecommerce_entityset

from featuretools import EntitySet, Relationship, variable_types
from featuretools.tests import integration_data


@pytest.fixture
def es():
    return make_ecommerce_entityset()


def test_cannot_readd_relationships_that_already_exists(es):
    before_len = len(es.relationships)
    es.add_relationship(es.relationships[0])
    after_len = len(es.relationships)
    assert before_len == after_len


def test_add_relationships_convert_type(es):
    for r in es.relationships:
        parent_e = es[r.parent_entity.id]
        child_e = es[r.child_entity.id]
        assert type(r.parent_variable) == variable_types.Index
        assert type(r.child_variable) == variable_types.Id
        assert parent_e.df[r.parent_variable.id].dtype == child_e.df[r.child_variable.id].dtype


def test_add_relationship_errors_on_dtype_mismatch(es):
    log_2_df = es['log'].df.copy()
    log_variable_types = {
        'id': variable_types.Categorical,
        'session_id': variable_types.Id,
        'product_id': variable_types.Id,
        'datetime': variable_types.Datetime,
        'value': variable_types.Numeric,
        'value_2': variable_types.Numeric,
        'latlong': variable_types.LatLong,
        'latlong2': variable_types.LatLong,
        'value_many_nans': variable_types.Numeric,
        'priority_level': variable_types.Ordinal,
        'purchased': variable_types.Boolean,
        'comments': variable_types.Text
    }
    es.entity_from_dataframe(entity_id='log2',
                             dataframe=log_2_df,
                             index='id',
                             variable_types=log_variable_types,
                             time_index='datetime',
                             encoding='utf-8')
    with pytest.raises(ValueError) as e:
        mismatch = Relationship(es['regions']['id'], es['log2']['session_id'])
        es.add_relationship(mismatch)

    assert e.value.__str__() == "Unable to add relationship because id in "\
                                "regions is Pandas dtype object and "\
                                "session_id in log2 is Pandas dtype int64."


def test_get_forward_entities(es):
    entities = es.get_forward_entities('log')
    assert entities == set(['sessions', 'products'])


def test_get_backward_entities(es):
    entities = es.get_backward_entities('sessions')
    assert entities == set(['log'])


def test_get_forward_entities_deep(es):
    entities = es.get_forward_entities('log', 'deep')
    assert entities == set(['sessions', 'customers', 'products', 'regions', 'cohorts'])


def test_get_backward_entities_deep(es):
    entities = es.get_backward_entities('customers', deep=True)
    assert entities == set(['log', 'sessions'])


def test_get_forward_relationships(es):
    relationships = es.get_forward_relationships('log')
    assert len(relationships) == 2
    assert relationships[0].parent_entity.id == 'sessions'
    assert relationships[0].child_entity.id == 'log'
    assert relationships[1].parent_entity.id == 'products'
    assert relationships[1].child_entity.id == 'log'

    relationships = es.get_forward_relationships('sessions')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'customers'
    assert relationships[0].child_entity.id == 'sessions'


def test_get_backward_relationships(es):
    relationships = es.get_backward_relationships('sessions')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'sessions'
    assert relationships[0].child_entity.id == 'log'

    relationships = es.get_backward_relationships('customers')
    assert len(relationships) == 1
    assert relationships[0].parent_entity.id == 'customers'
    assert relationships[0].child_entity.id == 'sessions'


def test_find_forward_path(es):
    path = es.find_forward_path('log', 'customers')

    assert len(path) == 2
    assert path[0].child_entity.id == 'log'
    assert path[0].parent_entity.id == 'sessions'
    assert path[1].child_entity.id == 'sessions'
    assert path[1].parent_entity.id == 'customers'


def test_find_backward_path(es):
    path = es.find_backward_path('customers', 'log')

    assert len(path) == 2
    assert path[0].child_entity.id == 'sessions'
    assert path[0].parent_entity.id == 'customers'
    assert path[1].child_entity.id == 'log'
    assert path[1].parent_entity.id == 'sessions'


def test_find_path(es):
    path, forward = es.find_path('products', 'customers',
                                 include_num_forward=True)

    assert len(path) == 3
    assert forward == 2
    assert path[0].child_entity.id == 'log'
    assert path[0].parent_entity.id == 'products'
    assert path[1].child_entity.id == 'log'
    assert path[1].parent_entity.id == 'sessions'
    assert path[2].child_entity.id == 'sessions'
    assert path[2].parent_entity.id == 'customers'


def test_raise_key_error_missing_entity(es):
    with pytest.raises(KeyError):
        es["this entity doesn't exist"]


def test_add_parent_not_index_varible(es):
    with pytest.raises(AttributeError):
        es.add_relationship(Relationship(es['regions']['language'],
                                         es['customers']['region_id']))


def test_serialization(es):
    dirname = os.path.dirname(integration_data.__file__)
    path = os.path.join(dirname, 'test_entityset.p')
    if os.path.exists(path):
        shutil.rmtree(path)
    es.to_pickle(path)
    new_es = EntitySet.read_pickle(path)
    assert es.__eq__(new_es, deep=True)
    shutil.rmtree(path)
